'use client';

import { Box, Switch, Select, Text, Flex } from '@chakra-ui/react';
import * as Yup from "yup";
import { FormDataProps } from '../variables/formData';
import { useRef, useState } from 'react';
import { InputWrapper, SelectWrapper } from '@/components/fields/Fields';
import useShowToast from '@/app/hooks/useShowToast';
import { useRouter } from 'next/navigation';
import FormComponent from '@/components/form/Form';

const validationSchema = Yup.object({
    MobileNo: Yup.string().required("Mobile number is required"),
    ContactInformation: Yup.string().required("Contact information is required"),
    Address: Yup.string().required("Address is required"),
    Premises: Yup.boolean().required("Premises in use is required"),
    MeterExist: Yup.boolean().required("Meter exist on site is required"),
    PremisesType: Yup.string().required("Premises type is required"),
    PropertyType: Yup.string().required("Property type is required"),
    MetersInstalled: Yup.string().required("Meters installed is required"),
    AdditionalMeterRequired: Yup.boolean().required("Additional meter required is required"),
    AdditionalMeterApplied: Yup.boolean().required("Additional meter applied is required"),
    AdditionalMeterRequirementArea: Yup.string().required("Additional meter requirement area is required"),
});

const Form = () => {
    const formRef = useRef(null);
    const router = useRouter();
    const showToast = useShowToast();
    const [formData, setFormData] = useState<FormDataProps>({} as FormDataProps);

    const initialValues = {
        id: formData.id ?? null,
        FullName: formData.FullName ?? '',
        ContactInformation: formData.ContactInformation ?? '',
        MeterNo: formData.MeterNo ?? '',
        Address: formData.Address ?? '',
        Premises: formData.Premises ?? false,
        MeterExist: formData.MeterExist ?? false,
        PremisesType: formData.PremisesType ?? '',
        PropertyType: formData.PropertyType ?? '',
        MetersInstalled: formData.MetersInstalled ?? '',
        AdditionalMeterRequired: formData.AdditionalMeterRequired ?? false,
        AdditionalMeterApplied: formData.AdditionalMeterApplied ?? false,
        AdditionalMeterRequirementArea: formData.AdditionalMeterRequirementArea ?? '',
    };

    const options = [
        { value: '1', text: 'One' },
        { value: '2', text: 'Two' },
        { value: '3', text: 'Three' },
    ];

    const handleSubmit = (values: FormData) => {
        console.log('Form values', values);
        if (values) {
            // handleUpdate(values);
        } else {
            // handleCreate(values);
        }
    }

    return (
        <>
            <FormComponent
                ref={formRef}
                validationSchema={validationSchema}
                initialValues={initialValues}
                // enableReinitialize // Ensures the form reinitializes with updated initial values
                submitForm={handleSubmit}

            >

                {/* Input Fields */}
                <InputWrapper id='FullName' type='text' fieldName='FullName' label='Full Name' placeholder='Full Name' extra='*' defaultValue={initialValues.FullName} />
                <InputWrapper id='ContactInformation' type='text' fieldName='ContactInformation' label='Contact Information' placeholder='Contact Information' extra='*' defaultValue={initialValues.ContactInformation} />
                <InputWrapper id='Address' type='text' fieldName='Address' label='Address' placeholder='Address' extra='*' defaultValue={initialValues.Address} />
                <InputWrapper id='MeterNo' type='text' fieldName='MeterNo' label='Meter No.' placeholder='Meter No.' extra='*' defaultValue={initialValues.MeterNo} />
                <InputWrapper id='AdditionalMeterRequirementArea' type='text' fieldName='AdditionalMeterRequirementArea' label='Additional Meter Requirement Area' placeholder='Additional Meter Requirement Area' defaultValue={initialValues.AdditionalMeterRequirementArea} />

                {/* Switch Fields */}
                <Flex flexDirection={'row'} justify={'space-between'} alignItems='center' mb='20px'>
                    <Text mr='10px'>Premises in use:</Text>
                    <Switch id='Premises' name='Premises' defaultChecked={initialValues.Premises} />
                </Flex>
                <Flex flexDirection={'row'} justify={'space-between'} alignItems='center' mb='20px'>
                    <Text mr='10px'>Meter exist on site:</Text>
                    <Switch id='MeterExist' name='MeterExist' defaultChecked={initialValues.MeterExist} />
                </Flex>

                {/* Select Fields */}
                <SelectWrapper id='PremisesType' fieldName='PremisesType' label='Premises Type' defaultValue={initialValues.PremisesType} options={options} />
                <SelectWrapper id='PropertyType' fieldName='PropertyType' label='Property Type' defaultValue={initialValues.PropertyType} options={options} />
                <SelectWrapper id='MetersInstalled' fieldName='MetersInstalled' label='Meters Installed' defaultValue={initialValues.MetersInstalled} options={options} />
                <Flex flexDirection={'row'} justify={'space-between'} alignItems='center' mb='20px'>
                    <Text mr='10px'>Additional meter required:</Text>
                    <Switch id='AdditionalMeterRequired' name='AdditionalMeterRequired' defaultChecked={initialValues.AdditionalMeterRequired} />
                </Flex>
                <Flex flexDirection={'row'} justify={'space-between'} alignItems='center' mb='20px'>
                    <Text mr='10px'>Additional meter applied:</Text>
                    <Switch id='AdditionalMeterApplied' name='AdditionalMeterApplied' defaultChecked={initialValues.AdditionalMeterApplied} />
                </Flex>

            </FormComponent>
        </>
    )
}

export default Form